CodecInto

Trait CodecInto 

pub trait CodecInto<T>: TopEncodeMulti
where T: TopDecodeMulti,
{ }
Signals that we can safely serialize Self in order to obtain a T on the other size.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F, I> CodecInto<F> for I
where I: TopEncodeMulti, F: CodecFrom<I>,